@@ -57,7 +57,7 @@ def parse_args() -> argparse.Namespace:
     _parser.add_argument('--max_iter', required=False, default=10, type=int, help=MAX_ITER_DESCRIPTION)
 
     _parser.add_argument('--timscore', default=False, action=argparse.BooleanOptionalAction, help=TIMSCORE_DESCRIPTION)
-    _parser.add_argument('--mass_alignment', default=True, action=argparse.BooleanOptionalAction, help=MASS_ALIGNMENT_DESCRIPTION)
+    _parser.add_argument('--mass_alignment', default=False, action=argparse.BooleanOptionalAction, help=MASS_ALIGNMENT_DESCRIPTION)
     _parser.add_argument('--mass_alignment_dim', required=False, default=1, type=int, help=MASS_ALIGNMENT_DIM_DESCRIPTION)
     _parser.add_argument('--mass_alignment_percentile', required=False, default=95, type=int,help=MASS_ALIGNMENT_PERCENTILE_DESCRIPTION)
     _parser.add_argument('--max_mline', required=False, default=None, type=int, help=MAX_MLINE_DESCRIPTION)
@@ -265,11 +265,17 @@ def mokafilter(sqts: Tuple[Iterator[IO[str]], List[str]],
         np.random.seed(seed)
 
     sqt_dfs = [convert_to_csv(sqt_io, sqt_stem, xcorr_filter, max_mline) for sqt_io, sqt_stem in zip(sqts[0], sqts[1])]
-    alignment_figs = None
+
+    alignment_figs = []
     if mass_alignment is True:
         print(f'Aligning masses...')
-        figs = [align_mass(sqt_df, mass_alignment_dim, mass_alignment_percentile) for sqt_df in sqt_dfs]
-        alignment_figs = figs
+        for i, sqt_df in enumerate(sqt_dfs):
+            fig = None
+            try:
+                fig = align_mass(sqt_df, mass_alignment_dim, mass_alignment_percentile)
+            except np.linalg.LinAlgError as err:
+                logging.error(f'Error aligning masses for sqt {i}: {err}')
+            alignment_figs.append(fig)
 
     sqt_df = pd.concat(sqt_dfs, ignore_index=True)
     pin_df = convert_to_moka(sqt_df)
@@ -277,15 +283,6 @@ def mokafilter(sqts: Tuple[Iterator[IO[str]], List[str]],
     fasta_elems = [_parse_protein(entry) for entry in _parse_fasta_files(fastas[0])]
     fasta_dict = {e[0]: {'sequence': e[1], 'description': e[2]} for e in fasta_elems}
 
-    """if enzyme_term is True:
-        pin_df['tryp'] = [
-            int(peptide[0] in enzyme_regex[1:-1]) + int(strip_modifications(peptide[:-2])[-1] in enzyme_regex[1:-1]) for
-            peptide in
-            sqt_df['sequence']]
-    else:
-        pin_df['tryp'] = [int(peptide[2] in enzyme_regex[1:-1]) + int(peptide[-1] in enzyme_regex[1:-1]) for peptide in
-                          sqt_df['sequence']]"""
-
     if any(sqt_df['tims_score']) and timscore is True:
         pin_df['tims_score'] = sqt_df['tims_score']
         pin_df['tims_score'] = pin_df['tims_score'].fillna(value=0)
@@ -304,19 +301,26 @@ def mokafilter(sqts: Tuple[Iterator[IO[str]], List[str]],
 
     psms.add_proteins(proteins)
 
+    # Select Model
     if xgboost:
         estimator = mokapot.Model(XGBClassifier(objective='binary:logistic', nthread=4, seed=42), max_iter=max_iter)
     else:
         estimator = mokapot.PercolatorModel(max_iter=max_iter)
 
-    results, models = mokapot.brew(psms=psms,
-                                   model=estimator,
-                                   test_fdr=test_fdr,
-                                   folds=folds,
-                                   max_workers=workers)
-
-    # results.to_txt(dest_dir=str(sqt_path.parent), file_root=str(sqt_path.stem))
-    print(models)
+    try:
+        results, models = mokapot.brew(psms=psms,
+                                       model=estimator,
+                                       test_fdr=test_fdr,
+                                       folds=folds,
+                                       max_workers=workers)
+    except RuntimeError as err:
+        logging.error(f'Runtime Error: {err} Likely too few PSMs...')
+        logging.info('Writing alignment figures, pin_df and empty DTASelect-filter.txt file.')
+        return alignment_figs, pin_df, StringIO('')
+    except ValueError as err:
+        logging.error(f'ValueError: {err} Likely too few PSMs...')
+        logging.info('Writing alignment figures, pin_df and empty DTASelect-filter.txt file.')
+        return alignment_figs, pin_df, StringIO('')
 
     # separate protein, peptide, and psm dataframes
     target_psm_results, target_peptide_results, target_protein_results = results.confidence_estimates['psms'], \
@@ -420,19 +424,17 @@ def mokafilter(sqts: Tuple[Iterator[IO[str]], List[str]],
     total_decoy_peptides = len(decoy_peptide_charge_pairs)
     decoy_spectra = sum([result.protein_lines[0].spectrum_count for result in decoy_results])
 
-    try:
+    protein_fdr = 'NA'
+    if (decoy_protein_groups + target_protein_groups) != 0:
         protein_fdr = round(decoy_protein_groups / (decoy_protein_groups + target_protein_groups) * 100, 4)
-    except ZeroDivisionError:
-        protein_fdr = 'NA'
 
-    try:
+    peptide_fdr = 'NA'
+    if (decoy_peptides + target_peptides) != 0:
         peptide_fdr = round(decoy_peptides / (decoy_peptides + target_peptides) * 100, 4)
-    except ZeroDivisionError:
-        peptide_fdr = 'NA'
-    try:
+
+    spectra_fdr = 'NA'
+    if (decoy_spectra + target_spectra) != 0:
         spectra_fdr = round(decoy_spectra / (decoy_spectra + target_spectra) * 100, 4)
-    except ZeroDivisionError:
-        spectra_fdr = 'NA'
 
     end_lines = [f'	Proteins	Peptide IDs	Spectra\n',
                  f'Unfiltered	{unfiltered_proteins}  {unfiltered_peptides}  {unfiltered_psms}\n',
